# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.0] - 2025-01-29

### Added

- Initial release of chatbot-connectors library
- Support for RASA chatbot connector
- Support for MillionBot chatbot connector  
- Support for Taskyto chatbot connector

### Features

- **RASA Connector**: Full support for RASA webhook API
- **MillionBot Connector**: Integration with MillionBot platform
- **Taskyto Connector**: Support for Taskyto chatbot API

[Unreleased]: https://github.com/Chatbot-TRACER/chatbot-connectors/compare/v0.1.0...HEAD
[0.1.0]: https://github.com/Chatbot-TRACER/chatbot-connectors/releases/tag/v0.1.0
